Update of /cvsroot/monetdb/pathfinder/compiler/include
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv1296/compiler/include

Modified Files:
      Tag: xquery-decomposition
        algopt.h mil.h properties.h sql_mnemonic.h 
Log Message:
propagated changes up to Thursday Jan 17 2008
from the development trunk to the xquery-decomposition branch


Index: mil.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/mil.h,v
retrieving revision 1.50
retrieving revision 1.50.2.1
diff -u -d -r1.50 -r1.50.2.1
--- mil.h       11 Jan 2008 10:47:06 -0000      1.50
+++ mil.h       17 Jan 2008 08:36:40 -0000      1.50.2.1
@@ -76,29 +76,30 @@
 #define PF_MIL_VAR_ATTR_CONT   26
 #define PF_MIL_VAR_QN_LOC      27
 #define PF_MIL_VAR_QN_URI      28
-#define PF_MIL_VAR_PROP_VAL    29
-#define PF_MIL_VAR_PROP_TEXT   30
-#define PF_MIL_VAR_PROP_COM    31
-#define PF_MIL_VAR_PROP_INS    32
-#define PF_MIL_VAR_PROP_TGT    33
+#define PF_MIL_VAR_QN_PREFIX   29
+#define PF_MIL_VAR_PROP_VAL    30
+#define PF_MIL_VAR_PROP_TEXT   31
+#define PF_MIL_VAR_PROP_COM    32
+#define PF_MIL_VAR_PROP_INS    33
+#define PF_MIL_VAR_PROP_TGT    34
 
-#define PF_MIL_VAR_LE          34
-#define PF_MIL_VAR_LT          35
-#define PF_MIL_VAR_EQ          36
-#define PF_MIL_VAR_GT          37
-#define PF_MIL_VAR_GE          38
+#define PF_MIL_VAR_LE          35
+#define PF_MIL_VAR_LT          36
+#define PF_MIL_VAR_EQ          37
+#define PF_MIL_VAR_GT          38
+#define PF_MIL_VAR_GE          39
 
-#define PF_MIL_VAR_TRACE_OUTER 39
-#define PF_MIL_VAR_TRACE_INNER 40
-#define PF_MIL_VAR_TRACE_ITER  41
-#define PF_MIL_VAR_TRACE_MSG   42
-#define PF_MIL_VAR_TRACE_ITEM  43
-#define PF_MIL_VAR_TRACE_TYPE  44
-#define PF_MIL_VAR_TRACE_REL   45
+#define PF_MIL_VAR_TRACE_OUTER 40
+#define PF_MIL_VAR_TRACE_INNER 41
+#define PF_MIL_VAR_TRACE_ITER  42
+#define PF_MIL_VAR_TRACE_MSG   43
+#define PF_MIL_VAR_TRACE_ITEM  44
+#define PF_MIL_VAR_TRACE_TYPE  45
+#define PF_MIL_VAR_TRACE_REL   46
 
-#define PF_MIL_VAR_TIME_LOAD   46
-#define PF_MIL_VAR_TIME_QUERY  47
-#define PF_MIL_VAR_TIME_PRINT  48
+#define PF_MIL_VAR_TIME_LOAD   47
+#define PF_MIL_VAR_TIME_QUERY  48
+#define PF_MIL_VAR_TIME_PRINT  49
 
 #define PF_MIL_RES_VAR_COUNT (PF_MIL_VAR_TIME_PRINT + 1)
 

Index: algopt.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/algopt.h,v
retrieving revision 1.20
retrieving revision 1.20.2.1
diff -u -d -r1.20 -r1.20.2.1
--- algopt.h    11 Jan 2008 10:47:04 -0000      1.20
+++ algopt.h    17 Jan 2008 08:36:39 -0000      1.20.2.1
@@ -52,6 +52,7 @@
 PFla_op_t * PFalgopt_key (PFla_op_t *root);
 PFla_op_t * PFalgopt_mvd (PFla_op_t *root, unsigned int noneffective_tries);
 PFla_op_t * PFalgopt_reqval (PFla_op_t *root);
+PFla_op_t * PFalgopt_rowrank (PFla_op_t *root);
 PFla_op_t * PFalgopt_set (PFla_op_t *root);
 PFla_op_t * PFalgopt_thetajoin (PFla_op_t *root);
 

Index: sql_mnemonic.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/sql_mnemonic.h,v
retrieving revision 1.33
retrieving revision 1.33.2.1
diff -u -d -r1.33 -r1.33.2.1
--- sql_mnemonic.h      11 Jan 2008 10:47:08 -0000      1.33
+++ sql_mnemonic.h      17 Jan 2008 08:36:40 -0000      1.33.2.1
@@ -52,7 +52,7 @@
 /* .......... Columns .......... */
 #define column_list(...)             PFsql_column_list(__VA_ARGS__)
 #define column_name(i)               PFsql_column_name(PF_SQL_ALIAS_UNBOUND,i)
-#define ref_column_name(a,n)         
PFsql_ref_column_name(PF_SQL_ALIAS_UNBOUND,n)
+#define ref_column_name(a,n)         PFsql_ref_column_name(a,n)
 #define ext_column_name(a,i)         PFsql_column_name(a,i)
 #define star()                       PFsql_star()
 


-------------------------------------------------------------------------
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2008.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins

Reply via email to
Index: properties.h
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/include/properties.h,v
retrieving revision 1.32
retrieving revision 1.32.2.1
diff -u -d -r1.32 -r1.32.2.1
--- properties.h        11 Jan 2008 12:49:10 -0000      1.32
+++ properties.h        17 Jan 2008 08:36:40 -0000      1.32.2.1
@@ -70,8 +70,10 @@
                                   unique values. */
     req_bool_val_t req_bool_vals; /**< List of attributes with their
                                        corresponding required values. */
-    PFalg_att_t  req_distr_cols;  /**< List of columns whose values only
-                                       have to have the same distribution. */
+    PFalg_att_t  req_order_cols;  /**< List of columns whose values need
+                                       to maintain the order. */
+    PFalg_att_t  req_bijective_cols;  /**< List of columns whose values have
+                                       to fulfill any bijective function. */
     PFalg_att_t  req_multi_col_cols; /**< List of columns that can be
                                        split up into multiple columns. */
     PFalg_att_t  req_value_cols;  /**< List of columns whose values are
@@ -446,10 +448,16 @@
 bool PFprop_req_bool_val_val (const PFprop_t *prop, PFalg_att_t attr);
 
 /**
  * Test if @a attr is in the list of distribution columns
  * in container @a prop
  */
-bool PFprop_req_distr_col (const PFprop_t *prop, PFalg_att_t attr);
+bool PFprop_req_order_col (const PFprop_t *prop, PFalg_att_t attr);
+
+/**
+ * Test if @a attr is in the list of bijective columns
+ * in container @a prop
+ */
+bool PFprop_req_bijective_col (const PFprop_t *prop, PFalg_att_t attr);
 
 /**
  * Test if @a attr is in the list of multi-col columns
@@ -446,10 +448,16 @@
 
 /**
- * Test if @a attr is in the list of distribution columns
+ * Test if @a attr is in the list of order columns
  * in container @a prop
  */
